==> goods-center-api-2.8.59-20200907.004611-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/sku/ItemSkuDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.sku;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xutao on 2018/11/5.
 */
public class ItemSkuDto implements Serializable {

    private static final long serialVersionUID = -414055513672681497L;
    private Long id;

    private Long itemId;

    //供应商建议零售价格
    private Long suggestMarketPrice;
    //划线价
    private Long facePrice;
    //供货价
    private Long salePrice;
    //库存id
    private Long stockId;

    private String attributeJson;
    //sku子图
    private String imgUrl;

    private Date gmtCreate;

    private Date gmtModified;
    //商家编码
    private String merchantCoding;

    //当前库存, 临时用
    private Integer remaining;
    //前库存, 临时用
    private Integer preRemaining;

    /** ******优惠券扩展字段（当前正在使用批次的信息）****** */
    /** 当前批次库存. */
    private Long currentStock;

    /** 当前批次初始库存. */
    private Long currentTotalStock;

    /**
     * 总库存
     */
    private Integer totalStock;
    /**
     * 有效期开始
     */
    private Date startDay;

    /**
     * 有效期结束
     */
    private Date endDay;

    /**
     * 卡券库id
     */
    private Long cardLibraryId;

    //补充：针对供应商商品是否可售, 兑吧本身商品在商品上面控制，但供应商商品在sku唯度控制
    private Integer onsale;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getSuggestMarketPrice() {
        return suggestMarketPrice;
    }

    public void setSuggestMarketPrice(Long suggestMarketPrice) {
        this.suggestMarketPrice = suggestMarketPrice;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }

    public Long getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(Long salePrice) {
        this.salePrice = salePrice;
    }

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public String getAttributeJson() {
        return attributeJson;
    }

    public void setAttributeJson(String attributeJson) {
        this.attributeJson = attributeJson;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getMerchantCoding() {
        return merchantCoding;
    }

    public void setMerchantCoding(String merchantCoding) {
        this.merchantCoding = merchantCoding;
    }

    public Integer getRemaining() {
        return remaining;
    }

    public void setRemaining(Integer remaining) {
        this.remaining = remaining;
    }

    public Integer getPreRemaining() {
        return preRemaining;
    }

    public void setPreRemaining(Integer preRemaining) {
        this.preRemaining = preRemaining;
    }

    public Integer getTotalStock() {
        return totalStock;
    }

    public void setTotalStock(Integer totalStock) {
        this.totalStock = totalStock;
    }

    public Date getStartDay() {
        return startDay;
    }

    public void setStartDay(Date startDay) {
        this.startDay = startDay;
    }

    public Date getEndDay() {
        return endDay;
    }

    public void setEndDay(Date endDay) {
        this.endDay = endDay;
    }

    public Long getCardLibraryId() {
        return cardLibraryId;
    }

    public void setCardLibraryId(Long cardLibraryId) {
        this.cardLibraryId = cardLibraryId;
    }

    public Long getCurrentStock() {
        return currentStock;
    }

    public void setCurrentStock(Long currentStock) {
        this.currentStock = currentStock;
    }

    public Long getCurrentTotalStock() {
        return currentTotalStock;
    }

    public void setCurrentTotalStock(Long currentTotalStock) {
        this.currentTotalStock = currentTotalStock;
    }

    public Integer getOnsale() {
        return onsale;
    }

    public void setOnsale(Integer onsale) {
        this.onsale = onsale;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> goods-center-api-2.9.85-20220121.032755-12-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/sku/ItemSkuDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.sku;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xutao on 2018/11/5.
 */
public class ItemSkuDto implements Serializable {

    private static final long serialVersionUID = -414055513672681497L;
    private Long id;

    private Long itemId;

    //供应商建议零售价格
    private Long suggestMarketPrice;
    //划线价
    private Long facePrice;
    //供货价
    private Long salePrice;
    //成本价
    private Long costPrice;
    // pop商品显示的兑换价
    private Long popShowPrice;
    //库存id
    private Long stockId;

    private String attributeJson;
    //sku子图
    private String imgUrl;

    private Date gmtCreate;

    private Date gmtModified;
    //商家编码
    private String merchantCoding;

    //当前库存, 临时用
    private Integer remaining;
    //前库存, 临时用
    private Integer preRemaining;

    /** ******优惠券扩展字段（当前正在使用批次的信息）****** */
    /** 当前批次库存. */
    private Long currentStock;

    /** 当前批次初始库存. */
    private Long currentTotalStock;

    /**
     * 总库存
     */
    private Integer totalStock;
    /**
     * 有效期开始
     */
    private Date startDay;

    /**
     * 有效期结束
     */
    private Date endDay;

    /**
     * 卡券库id
     */
    private Long cardLibraryId;

    //补充：针对供应商商品是否可售, 兑吧本身商品在商品上面控制，但供应商商品在sku唯度控制
    private Integer onsale;

    public Long getPopShowPrice() {
        return popShowPrice;
    }

    public void setPopShowPrice(Long popShowPrice) {
        this.popShowPrice = popShowPrice;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getSuggestMarketPrice() {
        return suggestMarketPrice;
    }

    public void setSuggestMarketPrice(Long suggestMarketPrice) {
        this.suggestMarketPrice = suggestMarketPrice;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }

    public Long getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(Long salePrice) {
        this.salePrice = salePrice;
    }

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public String getAttributeJson() {
        return attributeJson;
    }

    public void setAttributeJson(String attributeJson) {
        this.attributeJson = attributeJson;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getMerchantCoding() {
        return merchantCoding;
    }

    public void setMerchantCoding(String merchantCoding) {
        this.merchantCoding = merchantCoding;
    }

    public Integer getRemaining() {
        return remaining;
    }

    public void setRemaining(Integer remaining) {
        this.remaining = remaining;
    }

    public Integer getPreRemaining() {
        return preRemaining;
    }

    public void setPreRemaining(Integer preRemaining) {
        this.preRemaining = preRemaining;
    }

    public Integer getTotalStock() {
        return totalStock;
    }

    public void setTotalStock(Integer totalStock) {
        this.totalStock = totalStock;
    }

    public Date getStartDay() {
        return startDay;
    }

    public void setStartDay(Date startDay) {
        this.startDay = startDay;
    }

    public Date getEndDay() {
        return endDay;
    }

    public void setEndDay(Date endDay) {
        this.endDay = endDay;
    }

    public Long getCardLibraryId() {
        return cardLibraryId;
    }

    public void setCardLibraryId(Long cardLibraryId) {
        this.cardLibraryId = cardLibraryId;
    }

    public Long getCurrentStock() {
        return currentStock;
    }

    public void setCurrentStock(Long currentStock) {
        this.currentStock = currentStock;
    }

    public Long getCurrentTotalStock() {
        return currentTotalStock;
    }

    public void setCurrentTotalStock(Long currentTotalStock) {
        this.currentTotalStock = currentTotalStock;
    }

    public Integer getOnsale() {
        return onsale;
    }

    public void setOnsale(Integer onsale) {
        this.onsale = onsale;
    }

    public Long getCostPrice() {
        return costPrice;
    }

    public void setCostPrice(Long costPrice) {
        this.costPrice = costPrice;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
